@@ -76,7 +76,7 @@ parser.add_argument(
     help='The source path in which markdown should recursively find documentation.')
 
 parser.add_argument(
-    '-t', '--theme', dest='THEME', default='bootstrap-full',
+    '-t', '--theme', dest='THEME', default='rtd',
     help='Markment theme name or path')
 
 parser.add_argument(
